==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1ComponentStatusListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ComponentStatusListFluent<A extends V1ComponentStatusListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1ComponentStatus item);
    public A setToItems(int index,V1ComponentStatus item);
    public A addToItems(V1ComponentStatus... items);
    public A addAllToItems(Collection<V1ComponentStatus> items);
    public A removeFromItems(V1ComponentStatus... items);
    public A removeAllFromItems(Collection<V1ComponentStatus> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ComponentStatus> getItems();
    public List<V1ComponentStatus> buildItems();
    public V1ComponentStatus buildItem(int index);
    public V1ComponentStatus buildFirstItem();
    public V1ComponentStatus buildLastItem();
    public V1ComponentStatus buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ComponentStatusBuilder> predicate);
    public A withItems(List<V1ComponentStatus> items);
    public A withItems(V1ComponentStatus... items);
    public Boolean hasItems();
    public V1ComponentStatusListFluent.ItemsNested<A> addNewItem();
    public V1ComponentStatusListFluent.ItemsNested<A> addNewItemLike(V1ComponentStatus item);
    public V1ComponentStatusListFluent.ItemsNested<A> setNewItemLike(int index,V1ComponentStatus item);
    public V1ComponentStatusListFluent.ItemsNested<A> editItem(int index);
    public V1ComponentStatusListFluent.ItemsNested<A> editFirstItem();
    public V1ComponentStatusListFluent.ItemsNested<A> editLastItem();
    public V1ComponentStatusListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ComponentStatusBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> withNewMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ComponentStatusListFluent.MetadataNested<A> editMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ComponentStatusFluent<V1ComponentStatusListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ComponentStatusListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ComponentStatusListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ComponentStatusListFluent<A extends V1ComponentStatusListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1ComponentStatus item);
    public A setToItems(int index,V1ComponentStatus item);
    public A addToItems(V1ComponentStatus... items);
    public A addAllToItems(Collection<V1ComponentStatus> items);
    public A removeFromItems(V1ComponentStatus... items);
    public A removeAllFromItems(Collection<V1ComponentStatus> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ComponentStatus> getItems();
    public List<V1ComponentStatus> buildItems();
    public V1ComponentStatus buildItem(int index);
    public V1ComponentStatus buildFirstItem();
    public V1ComponentStatus buildLastItem();
    public V1ComponentStatus buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ComponentStatusBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1ComponentStatusBuilder> predicate);
    public A withItems(List<V1ComponentStatus> items);
    public A withItems(V1ComponentStatus... items);
    public Boolean hasItems();
    public V1ComponentStatusListFluent.ItemsNested<A> addNewItem();
    public V1ComponentStatusListFluent.ItemsNested<A> addNewItemLike(V1ComponentStatus item);
    public V1ComponentStatusListFluent.ItemsNested<A> setNewItemLike(int index,V1ComponentStatus item);
    public V1ComponentStatusListFluent.ItemsNested<A> editItem(int index);
    public V1ComponentStatusListFluent.ItemsNested<A> editFirstItem();
    public V1ComponentStatusListFluent.ItemsNested<A> editLastItem();
    public V1ComponentStatusListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ComponentStatusBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> withNewMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ComponentStatusListFluent.MetadataNested<A> editMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ComponentStatusListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ComponentStatusFluent<V1ComponentStatusListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ComponentStatusListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
